@@ -28,26 +28,22 @@ sub init ( $self ) {
 
     return $res unless $res;
 
-    my $roles = do {
-        no strict qw[refs];
-
-        ${ ref( $self->{app} ) . '::API_ROLES' };
-    };
+    my $roles = ${ ref( $self->{app} ) . '::API_ROLES' };
 
     # add api roles
     ( $res = $self->_db_add_roles( $self->{dbh}, $roles ) ) || return $res;
 
     # run hash RPC
-    print 'Starting API RPC ... ';
+    print 'Starting API RPC node ... ';
 
     say $self->{app}->{node}->run_node(
-        {   type      => 'Pcore::App::API::RPC::Hash',
+        {   type      => 'Pcore::App::API::Node',
             workers   => $self->{app}->{app_cfg}->{api}->{rpc}->{workers},
             buildargs => $self->{app}->{app_cfg}->{api}->{rpc}->{argon},
         },
     );
 
-    $self->{app}->{node}->wait_for('Pcore::App::API::RPC::Hash');
+    $self->{app}->{node}->wait_node('Pcore::App::API::Node');
 
     print 'Creating root user ... ';
 
@@ -94,7 +90,7 @@ sub _verify_token_hash ( $self, $private_token_hash, $hash ) {
         return $self->{_hash_cache}->{$cache_id};
     }
     else {
-        my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::RPC::Hash', 'verify_hash', $private_token_hash, $hash );
+        my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::Node', 'verify_hash', $private_token_hash, $hash );
 
         return $self->{_hash_cache}->{$cache_id} = $res->{data} ? res 200 : res [ 400, 'Invalid token' ];
     }
@@ -107,7 +103,7 @@ sub _generate_user_password_hash ( $self, $user_name_utf8, $user_password_utf8 )
 
     my $private_token_hash = sha3_512 $user_password_bin . $user_name_bin;
 
-    my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::RPC::Hash', 'create_hash', $private_token_hash );
+    my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::Node', 'create_hash', $private_token_hash );
 
     return $res if !$res;
 
@@ -121,7 +117,7 @@ sub _generate_token ( $self, $token_type ) {
 
     my $private_token_hash = sha3_512 $public_token;
 
-    my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::RPC::Hash', 'create_hash', $private_token_hash );
+    my $res = $self->{app}->{node}->rpc_call( 'Pcore::App::API::Node', 'create_hash', $private_token_hash );
 
     return $res if !$res;
 
@@ -276,7 +272,7 @@ sub set_user_permissions ( $self, $user_id, $permissions ) {
         return $res1 if !$res1;
 
         # fire event if user permissions was changed
-        P->fire_event('APP.API.AUTH') if $res == 200;
+        P->fire_event('app.api.auth') if $res == 200;
 
         return $res;
     }
@@ -326,7 +322,7 @@ sub set_user_password ( $self, $user_id, $password ) {
     return res 500 if !$res->{rows};
 
     # fire AUTH event if user password was changed
-    P->fire_event('APP.API.AUTH');
+    P->fire_event('app.api.auth');
 
     return res 200;
 }
@@ -349,7 +345,7 @@ sub set_user_enabled ( $self, $user_id, $enabled ) {
         return res 500 if !$res->{rows};
 
         # fire AUTH event if user was disabled
-        P->fire_event('APP.API.AUTH') if !$enabled;
+        P->fire_event('app.api.auth') if !$enabled;
 
         return res 200, { enabled => $enabled };
     }
@@ -475,7 +471,7 @@ sub remove_user_token ( $self, $user_token_id ) {
     # not found
     return res 204 if !$res->{rows};
 
-    P->fire_event('APP.API.AUTH');
+    P->fire_event('app.api.auth');
 
     return res 200;
 }
@@ -516,7 +512,7 @@ sub remove_user_session ( $self, $user_sid ) {
     # not found
     return res 204 if !$res->{rows};
 
-    P->fire_event('APP.API.AUTH');
+    P->fire_event('app.api.auth');
 
     return res 200;
 }
@@ -589,7 +585,7 @@ SQL
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 103, 131, 187        | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 99, 127, 183         | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
