@@ -9,8 +9,8 @@ has cookies => sub { {} };
 sub parse_cookies ( $self, $url, $set_cookie_header ) {
     $url = P->uri($url) if !is_ref $url;
 
-    my $origin_domain = $url->host->name;
-    my $origin_path   = $url->path->to_string;
+    my $origin_domain = $url->{host}->name;
+    my $origin_path   = $url->{path}->to_string;
 
   COOKIE: for my $str ( is_plain_arrayref $set_cookie_header ? $set_cookie_header->@* : $set_cookie_header ) {
         my $is_attr;
@@ -108,15 +108,15 @@ sub parse_cookies ( $self, $url, $set_cookie_header ) {
 sub get_cookies ( $self, $url ) {
     $url = P->uri($url) if !is_ref $url;
 
-    my $origin_is_secure = $url->is_secure;
-    my $origin_path      = $url->path->to_string;
+    my $origin_is_secure = $url->{is_secure};
+    my $origin_path      = $url->{path}->to_string;
 
     my @cookies;
 
-    my @origin_domains = ( $url->host->name );
+    my @origin_domains = ( $url->{host}->name );
 
-    if ( !$url->host->is_ip ) {
-        my $cover_domain = '.' . $url->host->name;
+    if ( !$url->{host}->is_ip ) {
+        my $cover_domain = '.' . $url->{host}->name;
 
         push @origin_domains, $cover_domain;
 
