@@ -11,15 +11,15 @@ has id => ( is => 'lazy', isa => Int, required => 1 );
 
 has network => ( is => 'ro', isa => Bool, default => 0 );
 
-has message => ( is => 'lazy', isa => Str, writer => '_set_message', default => q[] );
+has message => ( is => 'lazy', isa => Str, default => q[] );
 
 has show_state => ( is => 'lazy', isa => Bool, default => 1 );    # show value/total/percent
 
-has value => ( is => 'lazy', isa => PositiveOrZeroNum, writer => '_set_value', default => 0 );
+has value => ( is => 'lazy', isa => PositiveOrZeroNum, default => 0 );
 has value_format => ( is => 'ro', isa => Str | CodeRef, default => q[%.0f] );
 has _format_value => ( is => 'lazy', isa => CodeRef, init_arg => undef );
 
-has total => ( is => 'lazy', isa => PositiveOrZeroNum, writer => '_set_total', default => 0 );
+has total => ( is => 'lazy', isa => PositiveOrZeroNum, default => 0 );
 has total_format => ( is => 'ro', isa => Str | CodeRef, default => q[%.0f] );
 has _format_total => ( is => 'lazy', isa => CodeRef, init_arg => undef );
 
@@ -37,12 +37,12 @@ has _format_time => ( is => 'lazy', isa => CodeRef, init_arg => undef );
 
 has size => ( is => 'ro', isa => PositiveInt );
 
-has is_finished => ( is => 'rwp',  isa => Bool,              default => 0,          init_arg => undef );
-has start_time  => ( is => 'rwp',  isa => Int,               default => 0,          clearer  => '_clear_start_time', init_arg => undef );
-has end_time    => ( is => 'rwp',  isa => Int,               default => 0,          clearer  => '_clear_end_time', init_arg => undef );
-has total_time  => ( is => 'rwp',  isa => Int,               default => 0,          clearer  => '_clear_total_time', init_arg => undef );
-has eta         => ( is => 'lazy', isa => PositiveOrZeroNum, writer  => '_set_eta', default  => 0, init_arg => undef );                     # seconds, left to complete, 0 - unknown
-has speed => ( is => 'rwp', isa => PositiveOrZeroNum, init_arg => undef );
+has is_finished => 0, isa => Bool, init_arg => undef;
+has start_time  => 0, isa => Int,  init_arg => undef;
+has end_time    => 0, isa => Int,  init_arg => undef;
+has total_time  => 0, isa => Int,  init_arg => undef;
+has speed => ( isa => PositiveOrZeroNum, init_arg => undef );
+has eta => ( is => 'lazy', isa => PositiveOrZeroNum, default => 0, init_arg => undef );    # seconds, left to complete, 0 - unknown
 
 my $TERM_WIDTH = P->term->width;
 
@@ -169,13 +169,13 @@ sub _format_network_unit ( $self, $value ) {
 }
 
 sub start ($self) {
-    $self->_set_start_time(time);
+    $self->{start_time} = time;
 
-    $self->_clear_end_time;
+    delete $self->{end_time};
 
-    $self->_clear_total_time;
+    delete $self->{total_time};
 
-    $self->_set_is_finished(0);
+    $self->{is_finished} = 0;
 
     return;
 }
@@ -183,11 +183,11 @@ sub start ($self) {
 sub finish ($self) {
     my $time = time;
 
-    $self->_set_end_time($time);
+    $self->{end_time} = $time;
 
-    $self->_set_total_time( ( $time - $self->start_time ) || 1 );
+    $self->{total_time} = ( $time - $self->{start_time} ) || 1;
 
-    $self->_set_is_finished(1);
+    $self->{is_finished} = 1;
 
     return;
 }
@@ -195,43 +195,43 @@ sub finish ($self) {
 sub update ( $self, %args ) {
     my $time = time;
 
-    $self->_set_message( $args{message} ) if defined $args{message};
+    $self->{message} = $args{message} if defined $args{message};
 
-    $self->_set_total( $args{total} ) if defined $args{total};
+    $self->{total} = $args{total} if defined $args{total};
 
     # do not allow value to be larger than total
     $args{value} = $self->total if $self->total && $args{value} && $args{value} > $self->total;
 
-    $self->_set_value( $args{value} ) if defined $args{value};
+    $self->{value} = $args{value} if defined $args{value};
 
     # automatically finish
     if ( $self->value == $self->total ) {
         $self->finish;
     }
     else {
-        $self->_set_total_time( $time - $self->start_time );
+        $self->{total_time} = $time - $self->{start_time};
     }
 
     # calculate speed
-    if ( !defined $self->speed ) {
-        $self->_set_speed( int( $args{value} / ( $self->total_time || 1 ) ) );
+    if ( !defined $self->{speed} ) {
+        $self->{speed} = int( $args{value} / ( $self->{total_time} || 1 ) );
     }
     else {
-        $self->_set_speed( int( ( $self->speed + ( $args{value} / ( $self->total_time || 1 ) ) ) / 2 ) );
+        $self->{speed} = int( ( $self->{speed} + ( $args{value} / ( $self->{total_time} || 1 ) ) ) / 2 );
     }
 
     # calculate ETA
     if ( $self->total ) {
-        if ( !$self->speed ) {
-            $self->_set_eta(0);
+        if ( !$self->{speed} ) {
+            $self->{eta} = 0;
         }
         else {
-            $self->_set_eta( int( ( $self->total - $args{value} ) / $self->speed ) || 1 );
+            $self->{eta} = int( ( $self->total - $args{value} ) / $self->{speed} ) || 1;
         }
     }
 
     # redraw only every 0.5 sec., or if indicator is finished
-    return if !$self->is_finished && $LAST_UPDATED && $LAST_UPDATED + 0.5 > Time::HiRes::time();
+    return if !$self->{is_finished} && $LAST_UPDATED && $LAST_UPDATED + 0.5 > Time::HiRes::time();
 
     Pcore::Util::Term::Progress::_update();
 
